<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => 'Сжимает css и javascript файлов на публичной части сайта и в панели управления <code>ecrire/</code> ',
	'compresseur_slogan' => 'Плагин для сжатия CSS и Javascript файлов',
];
